@@ -4,7 +4,7 @@ import subprocess
 import os
 import sys
 import shutil
-import utility
+import lambdatool.utility
 import json
 
 logger = logging.getLogger()
@@ -20,10 +20,6 @@ class LambdaCreator:
     """
     Lambda utility is yet another tool create and deploy AWS lambda functions
     """
-    _config = None
-    _region = None
-    _profile = None
-
     def __init__(self, config_block):
         """
         Lambda utility init method.
@@ -43,6 +39,7 @@ class LambdaCreator:
             self._config = config_block
             self._profile = config_block['profile']
             self._region = config_block['region']
+            self._service = config_block['service']
         else:
             logger.error('config block was garbage')
             raise SystemError
@@ -112,7 +109,7 @@ class LambdaCreator:
         '''
         try:
             vpc_info = {}
-            ec2_client = utility.get_api_client(
+            ec2_client = lambdatool.utility.get_api_client(
                 self._profile,
                 self._region,
                 'ec2'
@@ -138,13 +135,14 @@ class LambdaCreator:
                     return vpc_info
         except Exception as wtf:
             logger.error('Exception caught in create_lambda(): {}'.format(wtf))
-            traceback.print_exc(file=sys.stdout)
+            logger.fatal(wtf, exc_info=False)
+            sys.exit(1)
 
         return {}
 
     def _find_lambda_role(self):
         try:
-            iam_client = utility.get_api_client(
+            iam_client = lambdatool.utility.get_api_client(
                 self._profile,
                 self._region,
                 'iam'
@@ -172,7 +170,7 @@ class LambdaCreator:
 
     def _find_default_security_group(self, vpc_id):
         try:
-            ec2_client = utility.get_api_client(
+            ec2_client = lambdatool.utility.get_api_client(
                 self._profile,
                 self._region,
                 'ec2'
@@ -196,7 +194,7 @@ class LambdaCreator:
     def _find_default_subnets(self, vpc_id):
         try:
             subnets = []
-            ec2_client = utility.get_api_client(
+            ec2_client = lambdatool.utility.get_api_client(
                 self._profile,
                 self._region,
                 'ec2'
@@ -262,7 +260,7 @@ class LambdaCreator:
             if 'security_group' in env_info:
                 ini_file.write('security_group={}\n'.format(env_info['security_group']))
             else:
-                ini_file.write('security_group=ADD_SECURITY_GROUP\n')
+                ini_file.write('#security_group=ENTER_A_SECURITY_GROUP_FOR_VPC\n')
 
             if 'subnets' in env_info:
                 wrk = str()
@@ -274,14 +272,29 @@ class LambdaCreator:
 
                 ini_file.write('subnets={}\n'.format(wrk))
             else:
-                ini_file.write('subnets=ADD_SUBNETS\n')
+                ini_file.write('#subnets=ENTER_A_COMMA_SEPARATED_LIST_OF_VPC_SUBNETS\n')
 
             if 'role' in env_info:
                 ini_file.write('role={}\n'.format(env_info['role']))
             else:
-                ini_file.write('role=ADD_YOUR_LAMBDA_IAM_ROLE\n')
+                role_arn = input("Enter execution role ARN (smash enter to skip): ")
+                parts = role_arn.split(':')
+                if len(parts) == 6 and role_arn.startswith('arn:aws:iam'):
+                    ini_file.write('role={}\n'.format(role_arn))
+                else:
+                    ini_file.write('role=ADD_YOUR_LAMBDA_IAM_ROLE\n')
 
             ini_file.write('memory=512\n')
-            ini_file.write('service=true\n')
-            ini_file.write('bucket=ADD_YOUR_ARTIFACT_BUCKET\n')
+
+            if self._service:
+                ini_file.write('service=true\n')
+            else:
+                ini_file.write('service=false\n')
+
+            bucket_name = input("Enter artifact bucket (smash enter to skip): ")
+            if len(bucket_name) == 0:
+                ini_file.write('bucket=ADD_YOUR_ARTIFACT_BUCKET\n')
+            else:
+                ini_file.write('bucket={}\n'.format(bucket_name))
+
             ini_file.write('\n')
