@@ -37,7 +37,7 @@ logging.basicConfig(level=logging.INFO,
 logging.getLogger().setLevel(logging.INFO)
 
 
-LAMBDATOOL_VERSION = '0.8.6'
+LAMBDATOOL_VERSION = '0.8.7'
 LAMBDATOOL_DESCRIPTOR = '.lambdatool'
 DEFAULT_DESCRIPTION = 'Fantastic Lambda Function'
 DEFAULT_MODULE_FILE = 'main.py'
@@ -121,9 +121,11 @@ class LambdaDeployer:
                 self._python = 'python3.7'
             elif v.minor == 8:
                 self._python = 'python3.8'
+            elif v.minor == 9:
+                self._python = 'python3.9'
             else:
                 logging.error('python %s.%s detected', v.major, v.minor)
-                logging.error('only python3.6, python3.7 and python3.8 are available')
+                logging.error('only python3.6, python3.7, python3.8 and python3.9 are available')
                 raise SystemError
         else:
             logging.error('strange python version')
